<?php

namespace Luticate\Auth\Controller;

use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticatePermissionsGroupsBusiness;
use Luticate\Auth\DBO\LuticatePermissionsGroupsDbo;

class LuticatePermissionsGroupsController extends LuController {
    protected function getBusiness()
    {
        return new LuticatePermissionsGroupsBusiness();
    }

    /**
     * Get all permissions for a group
     * @param $group_id int The group id
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @return \Luticate\Utils\LuMultipleDbo
     */
    public function getAllByGroup($group_id, $page = 0, $perPage = 2000000000)
    {
        return LuticatePermissionsGroupsBusiness::getAllByGroup($group_id, $page, $perPage);
    }

    /**
     * Get a permission group
     * @param $group_id int The group id
     * @param $permission_name string The permission name
     * @return LuticatePermissionsGroupsDbo
     */
    public function get($group_id, $permission_name)
    {
        return LuticatePermissionsGroupsBusiness::get($group_id, $permission_name);
    }

    /**
     * Add a permission for a group
     * @param $group_id int The group id
     * @param $permission_name string The permission name
     * @param $permission_value bool The permission value
     * @return bool
     */
    public function add($group_id, $permission_name, $permission_value)
    {
        return LuticatePermissionsGroupsBusiness::add($group_id, $permission_name, $permission_value);
    }

    /**
     * Delete a permission for a group
     * @param $group_id int The group id
     * @param $permission_name string The permission name
     * @return bool
     */
    public function del($group_id, $permission_name)
    {
        return LuticatePermissionsGroupsBusiness::del($group_id, $permission_name);
    }

    /**
     * Edit the permission value for a group
     * @param $group_id int The group id
     * @param $permission_name string The permission name
     * @param $permission_value bool The permission value
     * @return bool
     */
    public function edit($group_id, $permission_name, $permission_value)
    {
        return LuticatePermissionsGroupsBusiness::edit($group_id, $permission_name, $permission_value);
    }
}