<?php

namespace Luticate\Auth\Controller;

use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticateSettingsBusiness;
use Luticate\Auth\DBO\LuticateSettingsDbo;

class LuticateSettingsController extends LuController {
    protected function getBusiness()
    {
        return new LuticateSettingsBusiness();
    }

    /**
     * Get the effective setting for a user
     * @param $user_id int The user id
     * @param $setting_name string The setting name
     * @return LuticateSettingsDbo
     */
    public function getEffectiveSetting($user_id, $setting_name)
    {
        return LuticateSettingsBusiness::getEffectiveSetting($user_id, $setting_name);
    }

    /**
     * Get the effective setting for the logged user
     * @param $_user LuticateUsersDbo Logged user
     * @param $setting_name string The setting name
     * @return LuticateSettingsDbo
     */
    public function getEffectiveSettingMe($_user, $setting_name)
    {
        return LuticateSettingsBusiness::getEffectiveSetting($_user->getId(), $setting_name);
    }

    /**
     * Get all the effective setting for a user
     * @param $user_id int The user id
     * @return LuticateSettingsDbo[]
     */
    public function getAllEffectiveSetting($user_id)
    {
        return LuticateSettingsBusiness::getAllEffectiveSetting($user_id);
    }

    /**
     * Get all the effective setting for the logged user
     * @param $_user LuticateUsersDbo Logged user
     * @return LuticateSettingsDbo[]
     */
    public function getAllEffectiveSettingMe($_user)
    {
        return LuticateSettingsBusiness::getAllEffectiveSetting($_user->getId());
    }

    /**
     * Get a setting
     * @param $setting_name string The setting name
     * @return \Luticate\Utils\LuDbo
     */
    public function get($setting_name)
    {
        return LuticateSettingsBusiness::get($setting_name);
    }

    /**
     * Get all settings
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @param string $query The filter query
     * @return \Luticate\Utils\LuMultipleDbo
     */
    public function getAll($page = 0, $perPage = 2000000000, $query = "")
    {
        return LuticateSettingsBusiness::getAll($page, $perPage, $query);
    }

    /**
     * Add a setting
     * @param $setting LuticateSettingsDbo The setting
     * @return bool
     */
    public function add(LuticateSettingsDbo $setting)
    {
        return LuticateSettingsBusiness::add($setting);
    }

    /**
     * Remove a setting
     * @param $setting_name string The setting name
     * @return bool
     */
    public function del($setting_name)
    {
        return LuticateSettingsBusiness::del($setting_name);
    }

    /**
     * Edit the default setting value
     * @param $setting_name string The setting name
     * @param $setting LuticateSettingsDbo The setting
     * @return bool
     */
    public function edit($setting_name, LuticateSettingsDbo $setting)
    {
        return LuticateSettingsBusiness::edit($setting_name, $setting);
    }
}