<?php

namespace Luticate\Auth\DataAccess;

use Luticate\Auth\DataAccess\SP\SpLuGetAllUserSettings;
use Luticate\Auth\DataAccess\SP\SpLuGetUserSetting;
use Luticate\Utils\LuDataAccess;
use Luticate\Auth\DataAccess\Models\LuticateSettings;
use Luticate\Auth\DBO\LuticateSettingsDbo;

class LuticateSettingsDataAccess extends LuDataAccess {
    protected static function getModel()
    {
        return new LuticateSettings();
    }

    protected static function getOrderBy()
    {
        return array(array("name", "ASC"));
    }

    protected static function getQueryPredicate($query)
    {
        return array(array("name", "ilike", "%" . $query . "%", "or"));
    }

    public static function getEffectiveSetting($user_id, $setting_name)
    {
        return SpLuGetUserSetting::execute($user_id, $setting_name);
    }

    public static function getAllEffectiveSetting($user_id)
    {
        return SpLuGetAllUserSettings::getMultipleJson($user_id, 0, 2000000);
    }

    public static function getModelByName($setting_name)
    {
        return LuticateSettings::where("name", "=", $setting_name)->first();
    }

    /**
     * @param $setting_name string
     * @return LuticateSettingsDbo
     */
    public static function getByName($setting_name)
    {
        $perm = self::getModelByName($setting_name);
        if (is_null($perm)) {
            return null;
        }
        return $perm->toDbo();
    }

    public static function delete($setting_name)
    {
        $perm = self::getModelByName($setting_name);
        if (is_null($perm))
            return;
        $perm->delete();
    }

    /**
     * @param $setting_name string
     * @param $setting LuticateSettingsDbo
     */
    public static function edit($setting_name, $setting)
    {
        $perm = self::getModelByName($setting_name);
        if (is_null($perm))
            return;
        $perm->is_blocked = $setting->getIsBlocked();
        $perm->is_admin = $setting->getIsAdmin();
        $perm->value = $setting->getValue();
        $perm->save();
    }
}